@@ -17,12 +17,14 @@ import collections
 import datetime
 import functools
 import inspect
+import six
 import socket
 import threading
 
 from oslo_utils import reflection
 from oslo_utils import uuidutils
 
+from osprofiler import _utils as utils
 from osprofiler import notifier
 
 
@@ -30,7 +32,7 @@ from osprofiler import notifier
 __local_ctx = threading.local()
 
 
-def _clean():
+def clean():
     __local_ctx.profiler = None
 
 
@@ -157,7 +159,10 @@ def trace(name, info=None, hide_args=False, hide_result=True,
                 start(name, info=info_)
                 result = f(*args, **kwargs)
             except Exception as ex:
-                stop_info = {"etype": reflection.get_class_name(ex)}
+                stop_info = {
+                    "etype": reflection.get_class_name(ex),
+                    "message": six.text_type(ex)
+                }
                 raise
             else:
                 if not hide_result:
@@ -343,7 +348,10 @@ class Trace(object):
 
     def __exit__(self, etype, value, traceback):
         if etype:
-            info = {"etype": reflection.get_class_name(etype)}
+            info = {
+                "etype": reflection.get_class_name(etype),
+                "message": value.args[0] if value.args else None
+            }
             stop(info=info)
         else:
             stop()
@@ -359,6 +367,14 @@ class _Profiler(object):
         self._name = collections.deque()
         self._host = socket.gethostname()
 
+    def get_shorten_id(self, uuid_id):
+        """Return shorten id of a uuid that will be used in OpenTracing drivers
+
+        :param uuid_id: A string of uuid that was generated by uuidutils
+        :returns: A shorter 64-bit long id
+        """
+        return format(utils.shorten_id(uuid_id), "x")
+
     def get_base_id(self):
         """Return base id of a trace.
 
@@ -379,7 +395,7 @@ class _Profiler(object):
         """Start new event.
 
         Adds new trace_id to trace stack and sends notification
-        to collector (may be ceilometer). With "info" and 3 ids:
+        to collector. With "info" and 3 ids:
         base_id - to be able to retrieve all trace elements by one query
         parent_id - to build tree of events (not just a list)
         trace_id - current event id.
